SystemOrganization addCategory: #'DAO-SatelliteTests'!

TestCase subclass: #CommandParameterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!CommandParameterTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 16:32'!
testDeserializeNegativeSigned16BitInteger
	| serializedValue parameter streamDeLectura |
	
	serializedValue := #[1 1].
	streamDeLectura := ReadStream on: serializedValue.
	parameter := SignedIntegerCommandParameter new: 16.
	
	self assert: (parameter deserialize: streamDeLectura) equals: -1.! !

!CommandParameterTest methodsFor: 'deserialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/22/2013 16:35'!
testDeserializePositiveSigned16BitInteger
| serializedValue parameter streamDeLectura |
	
	serializedValue := #[0 1].
	streamDeLectura := ReadStream on: serializedValue.
	parameter := SignedIntegerCommandParameter new: 16.
	
	self assert: (parameter deserialize: streamDeLectura) equals: 1.! !

!CommandParameterTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 14:31'!
testSerializeString8
	| parameter |
	
	parameter := StringCommandParameter new: 8.
	parameter value: 'Hello'.
	
	self assert: (parameter serialize) equals: #[5 72 101 108 108 111].! !

!CommandParameterTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 14:27'!
testSerializeUnsigned32BitInteger
	| parameter |
	
	parameter := UnsignedIntegerCommandParameter new: 32.
	parameter value: 1.
	
	self assert: (parameter serialize) equals: #[0 0 0 1].! !

TestCase subclass: #CommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!CommandTest class methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:06'!
thermalSubsystemNameCommand

	^  Command getNameCommand.
	
! !

!CommandTest class methodsFor: 'as yet unclassified' stamp: 'EzequielDavidovichCaballero 10/9/2013 15:20'!
thermalSubsystemTelemetryCommand

	^  Command thermalTelemetry.
	
! !

!CommandTest methodsFor: 'deserialization' stamp: 'EzequielDavidovichCaballero 10/9/2013 15:57'!
testDeserializingArrayOfUnsigned8BitIntegerShouldReturnTheDecodedArray

	| encodedResponse decodedResponse readAddressCommand array |
	
	"setup"
	"001 sequence number, 1 first byte, 2 second"
	encodedResponse := #[0 0 1 1 2].

	readAddressCommand := Command memoryReadAddress.
	
	"exercise"	
	decodedResponse := readAddressCommand deserializeResponse: encodedResponse.
	
	"verify"
	self assert: (decodedResponse data size) equals: 1.
	
	array := (decodedResponse data at: 1).
	
	self assert: array size equals: 2.
	self assert: (array at: 1) equals: 1.
	self assert: (array at: 2) equals: 2.

! !

!CommandTest methodsFor: 'deserialization' stamp: 'EzequielDavidovichCaballero 10/2/2013 21:53'!
testDeserializingThermalNameResponseShouldReturnThermal

	| encodedResponse decodedResponse getNameCommand |

	"001 sequence number, lo que le sigue THERMAL codificado"
	encodedResponse := #[0 0 1 84 72 69 82 77 65 76].
	
	getNameCommand := Command getNameCommand.
	
	decodedResponse := getNameCommand deserializeResponse: encodedResponse.
	
	self assert: (decodedResponse data size) equals: 1.
	self assert: (decodedResponse data at: 1) equals: 'THERMAL'.! !

!CommandTest methodsFor: 'deserialization' stamp: 'EzequielDavidovichCaballero 10/9/2013 15:42'!
testDeserializingThermalSetMatrixKeyResponseShouldReturnVoid

	| encodedResponse thermalSetMatrixKeyCommand decodedResponse |
	
	"001 sequence number, then empty response"
	encodedResponse := #[0 0 1].
	
	thermalSetMatrixKeyCommand :=  Command thermalSetMatrixKey.
	
	decodedResponse :=  thermalSetMatrixKeyCommand deserializeResponse: encodedResponse.
	
	self assert: (decodedResponse class) equals: VoidCommandResponse.
	
! !

!CommandTest methodsFor: 'deserialization' stamp: 'EzequielDavidovichCaballero 10/9/2013 16:22'!
testDeserializingThermalShortTelemetryResponseShouldReturnThermalShortTelemetry

	| encodedResponse thermalShortTelemetryCommand decodedResponse |
	
	"001 sequence number, 1 battery temp"
	encodedResponse := #[0 0 1 1].
	thermalShortTelemetryCommand :=  Command thermalShortTelemetry.
	
	decodedResponse :=  thermalShortTelemetryCommand deserializeResponse: encodedResponse.
	
	self assert: (decodedResponse data at: 1) equals: 1.
	
! !

!CommandTest methodsFor: 'deserialization' stamp: 'EzequielDavidovichCaballero 10/2/2013 23:12'!
testDeserializingThermalTelemetryResponseContainingNegativeNumbersShouldDeserializeOK

	| encodedResponse decodedResponse thermalTelemetryCommand |
	
	"001 sequence number, 1 1 battery temp, 1 2 radio temp"
	encodedResponse := #[0 0 1 1 1 1 2].

	thermalTelemetryCommand := Command thermalTelemetry.
		
	decodedResponse := thermalTelemetryCommand deserializeResponse: encodedResponse.
	
	self assert: (decodedResponse data at: 1) equals: -1.
	self assert: (decodedResponse data at: 2) equals: -2.
! !

!CommandTest methodsFor: 'deserialization' stamp: 'EzequielDavidovichCaballero 10/2/2013 23:13'!
testDeserializingThermalTelemetryResponseShouldReturnThermalTelemetry

	| encodedResponse decodedResponse thermalTelemetryCommand |
	
	"001 sequence number, 0 1 battery temp, 0 2 radio temp"
	encodedResponse := #[0 0 1 0 1 0 2].

	thermalTelemetryCommand := Command thermalTelemetry.
		
	decodedResponse := thermalTelemetryCommand deserializeResponse: encodedResponse.
	
	self assert: (decodedResponse data at: 1) equals: 1.
	self assert: (decodedResponse data at: 2) equals: 2.
! !

!CommandTest methodsFor: 'deserialization' stamp: 'EzequielDavidovichCaballero 10/9/2013 20:39'!
testDeserializingUsigned32BitIntegerAndArrayOfUnsigned8BitIntegerShouldDeserializeOK

	| encodedResponse decodedResponse readLongAddressCommand array firstElement |
	
	"setup"
	"001 sequence number, 0 0 0 1 first element of the response,  then 1 and 2 are the elements of the array"
	encodedResponse := #[0 0 1 0 0 0 1 1 2].

	readLongAddressCommand := Command memoryReadLongAddress.
	
	"exercise"	
	decodedResponse := readLongAddressCommand deserializeResponse: encodedResponse.
	
	"verify"
	self assert: (decodedResponse data size) equals: 2.
	
	firstElement := decodedResponse data at: 1.
	self assert: firstElement equals: 1.
	
	array := (decodedResponse data at: 2).
	self assert: array size equals: 2.
	self assert: (array at: 1) equals: 1.
	self assert: (array at: 2) equals: 2.

! !

!CommandTest methodsFor: 'execution' stamp: 'EzequielDavidovichCaballero 10/2/2013 21:49'!
testSendingNameCommandToThermalSubsystem
	| thermalSubsystem nameCommand response |
	"setup"
	thermalSubsystem := SatelliteTest thermalSubsystem.
	nameCommand := Command getNameCommand.
	
	"exercise"
	response := nameCommand executeOn: thermalSubsystem.
	
	"verify"
	self assert: (response data at: 1) equals: 'THERMAL'! !

!CommandTest methodsFor: 'execution' stamp: 'EzequielDavidovichCaballero 10/9/2013 15:44'!
testSendingSetMatrixKeyCommandToThermalSubsystem
	| thermalSubsystem command response voidResponse |
	"setup"
	thermalSubsystem := SatelliteTest thermalSubsystem.
	command := Command thermalSetMatrixKey.
	voidResponse := VoidCommandResponse new.	
	"exercise"
	command addParameterValue: 10.
	response := command executeOn: thermalSubsystem.
	"verify"
	self assert: response equals: voidResponse.
	self assert: (thermalSubsystem getValueOfAttribute: 'matrix_key') equals: 10! !

!CommandTest methodsFor: 'serialization' stamp: 'EzequielDavidovichCaballero 10/9/2013 20:12'!
testSerializingCommandWithFiveU32ParametersShouldSerializeOK
	
	| command |
	
	command :=Command memoryReadChunkedAddress.

	command addParameterValue: 1.
	command addParameterValue: 2.
	command addParameterValue: 3.
	command addParameterValue: 4.
	command addParameterValue: 5.

	
	self assert: command serialize equals: #[45 0 0 0 1 0 0 0 2 0 0 0 3 0 0 0 4 0 0 0 5]! !

!CommandTest methodsFor: 'serialization' stamp: 'EzequielDavidovichCaballero 10/9/2013 16:35'!
testSerializingCommandWithMaxValueSetToOneU24ParameterShouldSerializeOK
	
	| command |
	
	command := Command powerStbSetSwitchesState.

	command addParameterValue: 16777215.
	
	self assert: command serialize equals: #[36 255 255 255]! !

!CommandTest methodsFor: 'serialization' stamp: 'EzequielDavidovichCaballero 10/9/2013 20:10'!
testSerializingCommandWithMaxValueSetToOneU8ParameterShouldSerializeOK
	
	| command |
	
	command := Command platformSetMode.

	command addParameterValue: 255.
	
	self assert: command serialize equals: #[32 255]! !

!CommandTest methodsFor: 'serialization' stamp: 'EzequielDavidovichCaballero 10/9/2013 20:40'!
testSerializingCommandWithMaxValuesSetToTwoU32ParametersShouldSerializeOK
	
	| command |
	
	command := Command memoryReadLongAddress.

	command addParameterValue: 4294967295.
	command addParameterValue: 4294967295.
	
	self assert: command serialize equals: #[44 255 255 255 255 255 255 255 255]! !

!CommandTest methodsFor: 'serialization' stamp: 'EzequielDavidovichCaballero 10/9/2013 16:36'!
testSerializingCommandWithOneU24ParameterShouldSerializeOK
	
	| command |
	
	command := Command powerStbSetSwitchesState.

	command addParameterValue: 1.
	
	self assert: command serialize equals: #[36 0 0 1]! !

!CommandTest methodsFor: 'serialization' stamp: 'EzequielDavidovichCaballero 10/9/2013 20:47'!
testSerializingCommandWithOneU32AndOneString8ParametersShouldSerializeOK
	
	| command |
	
	command := Command memoryWriteAddress.

	command addParameterValue: 1.
	command addParameterValue: 'Hello'.
	
	self assert: command serialize = #[33 0 0 0 1 5 72 101 108 108 111]! !

!CommandTest methodsFor: 'serialization' stamp: 'EzequielDavidovichCaballero 10/9/2013 15:44'!
testSerializingCommandWithOneU32ParameterShouldSerializeOK
	
	| command |
	
	command := Command thermalSetMatrixKey.

	command addParameterValue: 1.
	
	self assert: command serialize equals: #[32 0 0 0 1]! !

!CommandTest methodsFor: 'serialization' stamp: 'EzequielDavidovichCaballero 10/9/2013 20:45'!
testSerializingCommandWithTwoU32ParametersShouldSerializeOK
	
	| command |
	
	command :=Command memoryReadLongAddress.

	command addParameterValue: 1.
	command addParameterValue: 2.
	
	self assert: command serialize equals: #[44 0 0 0 1 0 0 0 2]! !

!CommandTest methodsFor: 'serialization' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 17:01'!
testSerializingCommandWithoutParametersShouldSerializeCommandIdOnly
	
	| command |
	
	command := CommandTest thermalSubsystemTelemetryCommand.
	
	self assert: command serialize equals: #[1]! !

TestCase subclass: #ControllerLogTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/17/2013 23:13'!
testWhenAskingForASequenceNumberNotLoggedTheResultShouldBeFalse
	| log |
	
	log := ControllerLog new.
	
	self deny: (log containsEntryWithSequenceNumber: 1)
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/13/2013 17:55'!
testWhenLoggingABeaconTheLogEntryShouldContainOnlyTheBeacon
	| log beacon data logEntry |
	
	"setup"
	log := ControllerLog new.
	
	data := OrderedCollection new.
	data add: 'BLAH'.
	beacon := DataCommandResponse newWithSequenceNumber: 16rFFFFF0 andData: data.
	
	"exercise"
	log addResponse: beacon withSequenceNumber: 16rFFFFF0 andBytes: #[1 2 3 4].
	
	"verify"
	self assert: log isEmpty not.
	logEntry := log entries first.
	self assert: (logEntry response) equals: beacon.
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/13/2013 17:56'!
testWhenLoggingABeaconTheLogEntryShouldContainTheBeaconAndTheCorrespondingByteArray
	| log beacon data logEntry |
	
	"setup"
	log := ControllerLog new.
	
	data := OrderedCollection new.
	data add: 'BLAH'.
	beacon := DataCommandResponse newWithSequenceNumber: 16rFFFFF0 andData: data.
	
	"exercise"
	log addResponse: beacon withSequenceNumber: 16rFFFFF0 andBytes: #[1 2 3 4].
	
	"verify"
	self assert: log isEmpty not.
	logEntry := log entries first.
	self assert: (logEntry response) equals: beacon.
	self assert: (logEntry responseBytes) equals: #[1 2 3 4].
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/13/2013 17:48'!
testWhenLoggingARequestTheLogEntryShouldContainTheCorrespondingBytes
	| log entry |
	
	log := ControllerLog new.
	
	log addRequest: 'telemetry' withSequenceNumber: 1 andBytes: #[1 2 3 4].
	
	self assert: (log containsEntryWithSequenceNumber: 1).
	entry := log entryWithSequenceNumber: 1.
	self assert: entry requestBytes equals: #[1 2 3 4].! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/13/2013 17:50'!
testWhenLoggingARequestTheSequenceNumberIsLogged
	| log |
	
	log := ControllerLog new.
	
	log addRequest: 'telemetry' withSequenceNumber: 1 andBytes: #[1 2 3 4].
	
	self assert: (log containsEntryWithSequenceNumber: 1)
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/13/2013 17:50'!
testWhenLoggingARequestUsingAnExistingSequenceNumberShouldArchiveTheOriginalRequest
	"log using a sequence number and then log again using the same sequence number, to make the log archive the first entry"
	| log newLogEntry logEntryForArchiving archivedLogEntry |
	
	"setup"
	log := ControllerLog new.
	log addRequest: 'messageMovedToTheArchive' withSequenceNumber: 1 andBytes: #[1 2 3 4].
	self assert: (log containsEntryWithSequenceNumber: 1).
	logEntryForArchiving := log entryWithSequenceNumber: 1.
	
	"exercise"
	"this should archive the first entry"
	log addRequest: 'expectedMessage' withSequenceNumber: 1 andBytes: #[1 2 3 4].
	
	"verify"
	newLogEntry := log entryWithSequenceNumber: 1.
	self assert: (newLogEntry request) equals: 'expectedMessage'.
	archivedLogEntry := log archive at: 1.
	self assert: archivedLogEntry equals: logEntryForArchiving.

! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/13/2013 17:54'!
testWhenLoggingAResponseUsingAnExistingSequenceNumberTheLogEntryShouldContainTheRequestAndTheResponse
	| log logEntry |
	
	"setup"
	log := ControllerLog new.
	log addRequest: 'requestMessage' withSequenceNumber: 1 andBytes: #[1 2 3 4].
		
	"exercise"
	log addResponse: 'responseMessage' withSequenceNumber: 1 andBytes: #[1 2 3 4].
	
	"verify"
	logEntry := log entryWithSequenceNumber: 1.
	self assert: (logEntry request) equals: 'requestMessage'.
	self assert: (logEntry response) equals: 'responseMessage'.
! !

!ControllerLogTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/13/2013 17:56'!
testWhenLoggingTwoBeaconsTheLogShouldContainBoth
	| log beacon data logEntry data2 beacon2 |
	
	"setup"
	log := ControllerLog new.
	
	data := OrderedCollection new.
	data add: 'beacon1'.
	beacon := DataCommandResponse newWithSequenceNumber: 16rFFFFF0 andData: data.

	data2 := OrderedCollection new.
	data2 add: 'beacon2'.
	beacon2 := DataCommandResponse newWithSequenceNumber: 16rFFFFF0 andData: data2 .

	"exercise"
	log addResponse: beacon withSequenceNumber: 16rFFFFF0 andBytes: #[1 2 3 4].
	log addResponse: beacon2 andBytes: #[1 2 3 4].
	
	"verify"
	self assert: log isEmpty not.
	logEntry := log entries first.
	self assert: (logEntry response) equals: beacon.
	logEntry := log entries second.
	self assert: (logEntry response) equals: beacon2.
! !

TestCase subclass: #SatelliteControllerTest
	instanceVariableNames: 'clientSocket'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/13/2013 09:47'!
testDeserealizeBeacon
	| satelliteController expectedBeacon serializedBeacon beacon |

	satelliteController := SatelliteController new.
	
	"255 255 240 header"
	"0 0 0 0 0 3 238 233 3 subsystem 0 telemetry"
	"0 0 77 68 subsystem 1 telemetry"
	"0 0 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 subsystem 2 telemetry"
	"255 255 255 255 subsystem 3 telemetry"
	"0 0 0 0 0 0 0 0 128 subsystem 4 telemetry"
	serializedBeacon := #[255 255 240 0 0 0 0 0 3 238 233 3 0 0 77 68 0 0 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 0 0 0 0 0 0 0 0 128 7 98 7 98 0 70 0 60 0 100 0 40 228 226].
	
	expectedBeacon := DataCommandResponse new.
	expectedBeacon add: ''.
	
	beacon := satelliteController decode: serializedBeacon.

	self assert: beacon equals: expectedBeacon.
! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/12/2013 20:15'!
testDeserealizeShortBeacon
	| satelliteController expectedBeacon serializedBeacon beacon |

	satelliteController := SatelliteController new.
	
	"255 255 243 header"
	"255 255 240 15 0 0 255 15 0 subsystem 0 telemetry"
	serializedBeacon := #[255 255 243 255 255 240 15 0 0 255 15 0 240 255 255 0 240 240 15 0 240 255 255 255 255 255 255 240 0 0 15 240 0 0 0 0 0 0 0 0 0 0 15 0 0 0 0].
	
	expectedBeacon := DataCommandResponse new.
	expectedBeacon add: 'A'.
	
	beacon := satelliteController decode: serializedBeacon.

	self assert: beacon equals: expectedBeacon.
! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EzequielDavidovichCaballero 10/9/2013 16:34'!
testEncodingNameCommandRequestShouldReturnCorrectString

	| satelliteController nameCommand resultingByteArray platformSubsystem |
	
	satelliteController := SatelliteController new.

	nameCommand :=  Command getNameCommand.
	platformSubsystem := SatelliteTest platformSubsystem.
	
	resultingByteArray := satelliteController encode: nameCommand forSubsystem: platformSubsystem withSequenceNumber: (SequenceNumber new).
	
	self assert: resultingByteArray equals:  #[78 129 151 0 0 1 0 0]! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EzequielDavidovichCaballero 10/9/2013 16:34'!
testEncodingSetMatrixKeyRequestShouldReturnCorrectString

	| satelliteController command resultingByteArray thermalSubsystem |
	
	satelliteController := SatelliteController new.

	command :=  Command thermalSetMatrixKey.
	command addParameterValue: 1.

	thermalSubsystem := SatelliteTest thermalSubsystem.
	
	resultingByteArray := satelliteController encode: command forSubsystem: thermalSubsystem withSequenceNumber: (SequenceNumber new).
	
	self assert: resultingByteArray equals:  #[225 246 60 0 0 1 3 32 0 0 0 1]! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EzequielDavidovichCaballero 10/9/2013 16:35'!
testEncodingTelemetryRequestShouldReturnCorrectString

	| satelliteController thermalTelCommand resultingByteArray thermalSubsystem |

	satelliteController := SatelliteController new.
	
	thermalTelCommand := Command thermalTelemetry.

	thermalSubsystem := SatelliteTest thermalSubsystem.
	
	resultingByteArray := satelliteController encode: thermalTelCommand forSubsystem: thermalSubsystem withSequenceNumber: (SequenceNumber new).

	self assert: resultingByteArray equals: #[90 204 175 0 0 1 3 1]! !

!SatelliteControllerTest methodsFor: 'messaging' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/13/2013 18:54'!
testReceivingAPackageFromRadioShouldLogEntryWithDecodedMessage

	| satellite radio satelliteController packages expectedBeacon messages |

	satellite := SatelliteTest satelliteWithAllSubsystems.
	
	radio := SatelliteControllerRadioStub newWithPackages: packages.	

	expectedBeacon := Beacon newFromSubsystems: satellite subsystems.
		
	satelliteController := SatelliteController newWith: radio.

	"exercise"
	messages := satelliteController getNewMessages.
	
	self assert: messages size equals: 1.
	self assert: (messages at: 1) equals: expectedBeacon.
! !

TestCase subclass: #SatelliteTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
cdhSubsystem
	| cdhSubsystem |

	cdhSubsystem := Subsystem cdh.
	cdhSubsystem setAttribute: 'lastSeenSequenceNumber' withValue: 10.
	cdhSubsystem setAttribute: 'nextBeaconEnableTicks' withValue: 20.
	cdhSubsystem setAttribute: 'antennaDeployStatus' withValue: 30.
	cdhSubsystem setAttribute: 'ticksLow' withValue: 40.
	
	^ cdhSubsystem! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
memorySubsystem
	| memorySub |

	memorySub := Subsystem memory.
	memorySub setAttribute: 'free' withValue: 100.
	
	^ memorySub! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
platformSubsystem
	| platformSub |

	platformSub := Subsystem platform.
	platformSub setAttribute: 'tick_count' withValue: 1000000.
	platformSub setAttribute: 'current_mode' withValue: 1.
	
	^ platformSub! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
powerSubsystem
	| powerSubsystem |

	powerSubsystem := Subsystem power.

	powerSubsystem setAttribute: 'low_voltage_counter' withValue: 1.
	powerSubsystem setAttribute: 'battery_v' withValue: 2.
	powerSubsystem setAttribute: 'array_X_v' withValue: 3.
	powerSubsystem setAttribute: 'array_Xp_mA' withValue: 4.
	powerSubsystem setAttribute: 'array_Xm_mA' withValue: 5.
	powerSubsystem setAttribute: 'array_Y_v' withValue: 6.
	powerSubsystem setAttribute: 'array_Yp_mA' withValue: 7.
	powerSubsystem setAttribute: 'array_Y_mA' withValue: 8.
	powerSubsystem setAttribute: 'array_Z_v' withValue: 9.
	powerSubsystem setAttribute: 'array_Zp_mA' withValue: 10.
	powerSubsystem setAttribute: 'array_Zm_mA' withValue: 11.
	powerSubsystem setAttribute: '_3v3_mA' withValue: 12.
	powerSubsystem setAttribute: '_5v_mA' withValue: 13.
	
	^ powerSubsystem! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/13/2013 18:39'!
satelliteWithAllSubsystems
	| subsystems |

	subsystems := OrderedCollection new.
	
	subsystems add: self platformSubsystem.
	subsystems add: self memorySubsystem.
	subsystems add: self powerSubsystem.
	subsystems add: self thermalSubsystem.
	subsystems add: self cdhSubsystem.

	^ Satellite newWithSubsystems: subsystems.
! !

!SatelliteTest class methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
thermalSubsystem
	| thermalSub |

	thermalSub := Subsystem thermal.
	thermalSub setAttribute: 'battery_temp' withValue: 10.
	thermalSub setAttribute: 'radio_temp' withValue: 20.
	
	^ thermalSub! !

!SatelliteTest methodsFor: 'receiving' stamp: 'EzequielDavidovichCaballero 10/9/2013 21:52'!
testDecodeThermalSubsystemNameCommand

	| satellite bytes getNameCommand decodedCommand satelliteController thermalSubsystem |

	"setup"
	satelliteController := SatelliteController new.
	satellite := SatelliteTest satelliteWithAllSubsystems.
	thermalSubsystem := SatelliteTest thermalSubsystem.
	getNameCommand := Command getNameCommand.
	bytes := satelliteController encode: getNameCommand forSubsystem: thermalSubsystem withSequenceNumber: SequenceNumber new.

	"exercise"	
	decodedCommand := satellite receive: bytes.

	"verify"	
	self assert: decodedCommand = getNameCommand.
! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:54'!
testGivenASatelliteWhenEmittingABeaconItShouldReturnCollectedTelemetry

	| satellite beacon expectedBeaconData subsystemsOrderedById |

	"setup"
	satellite := SatelliteTest satelliteWithAllSubsystems.

	subsystemsOrderedById := SortedCollection sortBlock: [ :current :new | current id < new id ].
	subsystemsOrderedById addAll: satellite subsystems.

	expectedBeaconData := subsystemsOrderedById collect: [ :subsystem | subsystem telemetry ].
	
	"exercise"	
	beacon := satellite emitBeacon.

	"verify"	
	self assert: beacon data size equals: satellite subsystems size.
	self assert: beacon data equals: expectedBeaconData.
! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/29/2013 17:35'!
testGivenASatelliteWhenEmittingAShortBeaconItShouldReturnCollectedShortTelemetry

	| satellite beacon expectedBeaconData subsystemsOrderedById |

	"setup"
	satellite := SatelliteTest satelliteWithAllSubsystems.
	
	subsystemsOrderedById := SortedCollection sortBlock: [ :current :new | current id < new id ].
	subsystemsOrderedById addAll: satellite subsystems.
	
	expectedBeaconData := subsystemsOrderedById collect: [ :subsystem | subsystem shortTelemetry ].
	
	"exercise"	
	beacon := satellite emitShortBeacon.

	"verify"	
	self assert: beacon data size equals: satellite subsystems size.
	self assert: beacon data equals: expectedBeaconData.
! !

!SatelliteTest methodsFor: 'beacon' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:54'!
testGivenASatelliteWithThermalSubsystemOnlyWhenEmittingABeaconTheBeaconShouldContainOnlyThermalTelemetry

	| satellite subsystems thermalSubsystem beacon expectedBeaconData subsystemsOrderedById |

	"setup"
	thermalSubsystem := Thermal new.
	thermalSubsystem setAttribute: 'battery_temp' withValue: '10'.
	thermalSubsystem setAttribute: 'radio_temp' withValue: '20'.
	
	subsystems := Set new.
	subsystems add: thermalSubsystem.
	
	satellite := Satellite newWithSubsystems: subsystems.

	subsystemsOrderedById := SortedCollection sortBlock: [ :current :new | current id < new id ].
	subsystemsOrderedById addAll: satellite subsystems.

	expectedBeaconData := subsystemsOrderedById collect: [ :subsystem | subsystem telemetry ].

	"exercise"	
	beacon := satellite emitBeacon.

	"verify"	
	self assert: beacon data size equals: satellite subsystems size.
	self assert: beacon data equals: expectedBeaconData.
! !

TestCase subclass: #SequenceNumberTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
test1AsByteArray
	| sequenceNumber |

	sequenceNumber := SequenceNumber new.

	self assert: sequenceNumber asByteArray equals: #[0 0 1].! !

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
testLastSequenceNumberAsByteArray
	| sequenceNumber lastNumber |
	
	lastNumber := LargePositiveInteger readFrom: 'FFFFF0' base: 16.

	sequenceNumber := SequenceNumber startingFrom: lastNumber.

	self assert: sequenceNumber asByteArray equals: #[255 255 240].! !

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
testNewSequenceNumberStartsIn1
	| sequenceNumber |
	
	sequenceNumber := SequenceNumber new.
	
	self assert: sequenceNumber number equals: 1! !

!SequenceNumberTest methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/21/2013 15:50'!
testNextOfLastNumberIs1
	| lastNumber sequenceNumber one |
	
	lastNumber := LargePositiveInteger readFrom: 'FFFFEF' base: 16.
	sequenceNumber := SequenceNumber startingFrom: lastNumber.
	one := sequenceNumber next.
	
	self assert: one equals: 1! !

TestCase subclass: #SubsystemTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
test01WhenCreatingASubsystemTheIdAndNameIsSet

	| subsystem |

	"setup"
	subsystem := Subsystem memory.

	"verify"	
	self assert: subsystem id equals: 1.
	self assert: subsystem name equals: 'MEMORY'.
! !

!SubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
test02WhenCreatingASubsystemItCanAnswerBasicCommands

	| subsystem |

	"setup"
	subsystem := Subsystem thermal.

	"verify"	
	self assert: (subsystem understands: 'name').
	self assert: (subsystem understands: 'telemetry').
	self assert: (subsystem understands: 'short_telemetry').
! !

!SubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:34'!
test03WhenCreatingASubsystemItDoesntUnderstandUnknwonCommand

	| subsystem  |

	"setup"
	subsystem := Subsystem memory.

	"verify"	
	self deny: (subsystem understands: 'notACommand').
! !

!SubsystemTest methodsFor: 'subsystem' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 9/29/2013 19:34'!
test04ThermalShortTelemetryShouldReturnOK

	| subsystem expectedShortTelemetry shortTelemetry data |

	"setup"
	subsystem := SatelliteTest thermalSubsystem.
	data := OrderedCollection new.
	data add: (Association key: 'battery_temp' value: 10).
	expectedShortTelemetry := DataCommandResponse newWithData: data.
	
	"excercise"
	shortTelemetry:=	subsystem shortTelemetry. 

	"verify"	
	self assert: shortTelemetry = expectedShortTelemetry.

! !

!SubsystemTest methodsFor: 'subsystem' stamp: 'EzequielDavidovichCaballero 10/2/2013 22:54'!
test05ThermalTelemetryShouldReturnOK

	| subsystem expectedTelemetry telemetry data |

	"setup"
	subsystem := SatelliteTest thermalSubsystem.
	data := OrderedCollection new.
	data add: (Association key: 'battery_temp' value: 10).
	data add: (Association key: 'radio_temp' value: 20).
	expectedTelemetry := DataCommandResponse newWithData: data.
	
	"excercise"
	telemetry:= subsystem telemetry. 

	"verify"	
	self assert: telemetry = expectedTelemetry.

! !

Object subclass: #SatelliteControllerRadioStub
	instanceVariableNames: 'packages'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DAO-SatelliteTests'!

!SatelliteControllerRadioStub class methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/13/2013 19:09'!
newWithPackages: aCollection 
	^ self new initializeWithPackages: aCollection.! !

!SatelliteControllerRadioStub methodsFor: 'as yet unclassified' stamp: 'EmilianoMenendezEzequielDavidovichCaballero 10/13/2013 19:10'!
initializeWithPackages: aCollection 
	packages := aCollection.! !
